function [t,num_alleles_all,FN_ratio_all,B_all,F_all,M_all,DM_all,N_all,N_p_all,num_alleles_Aland,succ_mig_repr,f_all,OrderX,g,Females_thisGen,num_msats_alleles,FST_all,FST_allLoci,AC_allLoci,num_csd_alleles] = Hyperparas_Core(seedi,ngen,fluctScale,num_csd_alleles,mutr,u,larvPerNest,Mesomort,Hypomort,num_msats,num_msats_alleles,h,sig,asymp,rise,inviable,check_migRate,rho,startyr,d1,d2,mutr_msat,s0,FST_on)

% random seed
rng(seedi,'twister')

% larvae population
[B_all,OrderX,g] = butterfly_tseries(fluctScale,ngen,u,rho,startyr);

%% additional parameters 
p = 1; % probability of DM to mate, relative to haploid males (Fauvergue et al. 2015)
F_0 = 900; % the initial population size of female hyperparasitoids
f_0 = 0.6; % initial rate of hyperparasitism

% connectivity matrix
U = reshape(1:u,d2,d1)';
C = zeros(u,u);
for i = 1:d1
    for j = 1:d2
        
        if j-1>0
            C(U(i,j-1),U(i,j)) = 1;
        end
        
        if i-1>0
            C(U(i-1,j),U(i,j)) = 1;
        end
        
        if j+1<d2+1
            C(U(i,j+1),U(i,j)) = 1;
        end
        
        if i+1<d1+1
            C(U(i+1,j),U(i,j)) = 1;
        end
        
    end
end
C = h*(C./repmat(sum(C,1),u,1));

% initialization of the state vectors
N_all = zeros(u,ngen); % number of parasitoids
N_p_all = N_all; % number of parasitized parasitoids
F_all = N_all; % number of female hyperparasitoids
M_all = N_all; % number of male hyperparasitoids
DM_all = N_all; %  number of diploid males
f_all = N_all; % the vector that contains the rates of hyperparasitism
FN_ratio_all = N_all; % The ratio female hyperparasitoid:parasitoid
num_alleles_all = N_all; % number of unique CSD alleles, local
num_alleles_Aland = zeros(1,ngen); % number of unique CSD alleles, Aland
succ_mig_repr = zeros(u,ngen); % the number of successful migrants
FST_all = zeros(50,3); % vector that contains Fst values calculated using the neutral msat markers
FST_k = 0; % count for the stops made to calculate Fst values
FST_allLoci = zeros(50,num_msats); % vector that contains Fst values
AC_allLoci = zeros(50,num_msats); % vector that contains the number of unique msat alleles

% initial conditions
for region = 1:u
    N_all(region,1) =sum(rand(1,round(B_all(region,1))) < 1/3); 
end

f_all(1:u,1) = f_0;
FN_ratio_all(1:u,1) = F_0/N_all(:,1);

for region = 1:u
    N_p_all(region,1) = sum(rand(1,N_all(region,1)) < f_all(region,1)); % number of parasitized Hyposoter
    F_all(region,1) = sum(rand(1,N_p_all(region,1)) > s0); % number of female Mesochorus
end

N_all(:,1) = N_all(:,1)-N_p_all(:,1);
M_all(:,1) = round((N_p_all(:,1)-F_all(:,1))*(1-Mesomort)); % number of male Mesochorus
F_all(:,1) = round(F_all(:,1)*(1-Mesomort));
DM_all(:,1) = 0;

% initializing individuals
Females_thisGen = [];
Males_thisGen = [];
DipMales_thisGen = [];

for region = 1:u
    
    Females = zeros(F_all(region,1),2+num_msats*2); % diploid
    Females(:,1) = randsample(1:num_csd_alleles,F_all(region,1),true);
    Females(:,2) = randsample(1:num_csd_alleles,F_all(region,1),true);
    
    for msats = 1:num_msats*2
        Females(:,2+msats) = randsample(1:num_msats_alleles,F_all(region,1),true);
    end
    
    Q = find((Females(:,1)-Females(:,2))==0);
    while ~isempty(Q)
        Females(Q,1) = randsample(1:num_csd_alleles,length(Q),true);
        Females(Q,2) = randsample(1:num_csd_alleles,length(Q),true);
        Q = find((Females(:,1)-Females(:,2))==0);
    end
    
    Males = zeros(M_all(region,1),1+num_msats); % haploid
    Males(:,1) = randsample(1:num_csd_alleles,M_all(region,1),true);
    
    for msats = 1:num_msats
        Males(:,1+msats) = randsample(1:num_msats_alleles,M_all(region,1),true);
    end
    
    DipMales = zeros(0,2+num_msats*2);
    
    % store the individuals
    Females_thisGen = [Females_thisGen;1*ones(size(Females,1),1),region*ones(size(Females,1),1),Females];% t, region, genotypes(2), microsats
    Males_thisGen = [Males_thisGen;1*ones(size(Males,1),1),region*ones(size(Males,1),1),Males]; % t, region, genotypes(1), microsats
    
    num_alleles_all(region,1) = size(unique([reshape(Females(:,1:2),size(Females,1)*2,1);Males(:,1)]),1);
    
end
num_alleles_Aland(1,1) = length(unique([reshape(Females_thisGen(:,3:4),size(Females_thisGen,1)*2,1);Males_thisGen(:,3)])); % at the CSD loci

% iteration over (ngen - 1) generations
for t = 2:ngen
    
    Females_prevGen = Females_thisGen; Females_thisGen = [];
    Males_prevGen = Males_thisGen; Males_thisGen = [];
    DipMales_prevGen = DipMales_thisGen; DipMales_thisGen = [];
    
    for region = 1:u
        
        if mod(t,100) == 0 && region == 1
            display(['t = ', num2str(t)])
        end
        
        % population sizes after mortality between eclosion and oviposition
        N = sum(rand(1,round(B_all(region,t))) < 1/3); % number of hyposoters -- hyp is always 1/3 of butterflies (B)
        N = sum(rand(1,N)<(1-Hypomort)); % mortality of Hyposoter between birth until hyperparasitism
        F = sum(rand(1,F_all(region,t-1))<(1-Mesomort)); % mortality of hyperparasitoids
        M = sum(rand(1,M_all(region,t-1))<(1-Mesomort));
        DM = sum(rand(1,DM_all(region,t-1))<(1-Mesomort));
        
        % arrays for individuals (genes only)
        Females = Females_prevGen((Females_prevGen(:,1)==t-1 & Females_prevGen(:,2)==region),3:4+num_msats*2);
        Males = Males_prevGen((Males_prevGen(:,1)==t-1 & Males_prevGen(:,2)==region),3:3+num_msats);
        
        if ~isempty(DipMales_prevGen)
            DipMales = DipMales_prevGen((DipMales_prevGen(:,1)==t-1 & DipMales_prevGen(:,2)==region),3:4+num_msats*2);
        end
        
        % remove proportion dead
        PPf = randperm(size(Females,1),F);
        PPm = randperm(size(Males,1),M);        
        PPdm = randperm(size(DipMales,1),DM);
        Females=Females(PPf,:);
        Males=Males(PPm,:);
        DipMales=DipMales(PPdm,:);
        if isempty(DipMales)
            DipMales = zeros(0,2+num_msats*2);
        end
        
        if t > 2 && check_migRate == 1 % checking successful migrants; DMs do not have any offspring = never successful migrants
            % dispersers have 1 in the second column
            who_disp_f = I_disp_f_all((Females_prevGen(:,1)==t-1 & Females_prevGen(:,2)==region),:);
            who_disp_f = who_disp_f(PPf,:);
            who_disp_m = I_disp_m_all((Males_prevGen(:,1)==t-1 & Males_prevGen(:,2)==region),:);
            who_disp_m = who_disp_m(PPm,:);
        end
            
        f = (randn(1)*sig+1)*asymp*(1-exp(-rise*F/N)); % rate of hyperparasitism
        while f < 0 || f > 1
            f = (randn(1)*sig+1)*asymp*(1-exp(-rise*F/N));
        end
        FN_ratio_all(region,t) = F/N;
        
        N_p = sum(rand(1,N) < f); % number of hyposoters parasitized
        N = N-N_p;
        
        if F > 0 && M+DM > 0 % there are females and males
            
            % reproduction
            % assign a male to each female Mesochorus
            % mating: random, females mate singly. Males can remate. (monoandrous-polygynous mating system)
            Female_ids = 1:F;
            Male_ids = 1:M;
            DipMale_ids = (M+1):(M+DM);
            Males_chosen = randsample([Male_ids,DipMale_ids]',F,true,[ones(1,M),p*ones(1,DM)]);
            
            % assign parents to each offspring
            num_offsp = N_p; % number of parasitized Hyposoter = number of Mesochorus offspring
            mothers = randsample(Female_ids,num_offsp,true,ones(size(Female_ids))'-(1-s0)*(Males_chosen>M));% mothers mated with DMs have eggs only to become sons
            fathers = Males_chosen(mothers)'; % fathers
            
            % sex of the offspring
            if inviable == 0 || inviable == 1 || inviable == 3 % the mode of inviability of DM
                sex_offsp = (fathers<=M).*(rand(1,num_offsp)>s0); % daughters have normal fathers and the mothers wanted daughters (1-s0)
            elseif inviable == 2
                sex_offsp = (rand(1,num_offsp) > s0); % 0 = sons, 1 = daughters
            end
            
            % to check if migrants really reproduced or not
            if t > 2 && check_migRate == 1
                Y = find(who_disp_f(:,2)==1); % yes dispersed
                if ~isempty(Y)
                    for l = 1:length(Y)
                        succ_mig_repr(region,t) = succ_mig_repr(region,t) + ...
                            ((sum(sex_offsp(mothers == Y(l)) == 0) + sum(sex_offsp(mothers == Y(l))==1 & fathers(mothers == Y(l)) < M))>0); % reproduced or not
                    end
                end
                
                X = find(who_disp_m(:,2)==1);
                if ~isempty(X)
                    for l = 1:length(X)
                        succ_mig_repr(region,t) = succ_mig_repr(region,t) + (sum(sex_offsp(fathers == X(l)) == 1) > 0);
                    end
                end
                
            end
            
            % recombination CSD and then msats
            sons = Females(mothers(sex_offsp == 0),:); % sons
            which_locus = rand(size(sons,1),1)<0.5;
            sons(:,1) = sons(:,1).*which_locus + sons(:,2).*(1-which_locus);
            
            if num_msats > 0
            which_locus = rand(size(sons,1),num_msats)<0.5;
            sons(:,3:2+num_msats) = sons(:,3:2+num_msats).*which_locus + sons(:,3+num_msats:2+num_msats*2).*(1-which_locus);
            end
            sons = sons(:,[1,3:2+num_msats]); 
            
            if inviable == 0 || inviable == 1 || inviable == 3 
                daughters = Females(mothers(sex_offsp == 1 & fathers <= M),:); % mothers producing daughters and mated with a normal male
                which_locus = rand(size(daughters,1),1)<0.5;
                daughters(:,1) = daughters(:,1).*which_locus + daughters(:,2).*(1-which_locus); % one out of two randomly from the mother
                daughters(:,2) = Males(fathers(sex_offsp == 1 & fathers <= M),1); % one from the father
                
                if num_msats > 0
                which_locus = rand(size(daughters,1),num_msats)<0.5;
                daughters(:,3:2+num_msats) = daughters(:,3:2+num_msats).*which_locus + daughters(:,3+num_msats:2+num_msats*2).*(1-which_locus);
                daughters(:,3+num_msats:2+num_msats*2) = Males(fathers(sex_offsp == 1 & fathers <= M),2:1+num_msats);
                end
                
            elseif inviable == 2 % fully fertile DMs (but still males)
                daughters_male = Females(mothers(sex_offsp == 1 & fathers <= M),:); % mothers producing daughters and mated with a normal male
                which_locus = rand(size(daughters_male,1),1)<0.5;
                daughters_male(:,1) = daughters_male(:,1).*which_locus + daughters_male(:,2).*(1-which_locus); % one out of two randomly from the mother
                daughters_male(:,2) = Males(fathers(sex_offsp == 1 & fathers <= M),1); % one from the father
                
                if num_msats > 0
                which_locus = rand(size(daughters_male,1),num_msats)<0.5;
                daughters_male(:,3:2+num_msats) = daughters_male(:,3:2+num_msats).*which_locus + daughters_male(:,3+num_msats:2+num_msats*2).*(1-which_locus);
                daughters_male(:,3+num_msats:2+num_msats*2) = Males(fathers(sex_offsp == 1 & fathers <= M),2:1+num_msats);
                end
                
                daughters_dm = Females(mothers(sex_offsp == 1 & fathers > M),:); % mothers producing daughters and mated with diploid male
                if size(daughters_dm,1)>0 
                    which_locus = rand(size(daughters_dm,1),1)<0.5;
                    daughters_dm(:,1) = daughters_dm(:,1).*which_locus + daughters_dm(:,2).*(1-which_locus); % one out of two randomly from the mother
                    which_locus = rand(size(daughters_dm,1),1)<0.5;
                    daughters_dm(:,2) = DipMales(fathers(sex_offsp == 1 & fathers > M)-size(Males,1),1).*which_locus + DipMales(fathers(sex_offsp == 1 & fathers > M)-size(Males,1),2).*(1-which_locus);
                    
                    if num_msats > 0
                    which_locus = rand(size(daughters_dm,1),num_msats)<0.5;
                    daughters_dm(:,3:2+num_msats) = daughters_dm(:,3:2+num_msats).*which_locus + daughters_dm(:,3+num_msats:2+num_msats*2).*(1-which_locus);
                    daughters_dm(:,3+num_msats:2+num_msats*2) = DipMales(fathers(sex_offsp == 1 & fathers > M)-size(Males,1),3:2+num_msats).*which_locus + DipMales(fathers(sex_offsp == 1 & fathers > M)-size(Males,1),3+num_msats:2+num_msats*2).*(1-which_locus);
                    end
                    
                end
                daughters = [daughters_male; daughters_dm];
            else
                error('something is wrong in mating')
            end
            
            if inviable == 0 || inviable == 1 || inviable == 2
                DipMales = daughters((daughters(:,1)-daughters(:,2))==0,:); % Homozygotes become DMs
                daughters((daughters(:,1)-daughters(:,2))==0,:) = [];
            end
            
            % generation change
            Females = daughters;
            Males = sons;
            
            % mutations -- CSD
            dna = [reshape(Females(:,1:2),size(Females,1)*2,1);Males(:,1);reshape(DipMales(:,1:2),size(DipMales,1)*2,1)]';
            toMutate = (rand(1,length(dna)) < mutr);
            
            if sum(toMutate)>0
                dna(toMutate) = (num_csd_alleles+1):(num_csd_alleles+sum(toMutate));
                num_csd_alleles = num_csd_alleles + sum(toMutate);
            end
            
            Females(:,1:2) = reshape(dna(1:size(Females,1)*2),size(Females,1),2);
            Males(:,1) = dna(size(Females,1)*2+1:size(Females,1)*2+size(Males,1))';
            DipMales(:,1:2) = reshape(dna(size(Females,1)*2+size(Males,1)+1:size(Females,1)*2+size(Males,1)+size(DipMales,1)*2),size(DipMales,1),2);
            
            % mutations -- msats
            if num_msats > 0
                dna = [reshape(Females(:,3:2+num_msats*2),size(Females,1)*num_msats*2,1);reshape(Males(:,2:1+num_msats),size(Males,1)*num_msats,1);reshape(DipMales(:,3:2+num_msats*2),size(DipMales,1)*num_msats*2,1)]';
                toMutate = (rand(1,length(dna)) < mutr_msat);
                
                if sum(toMutate) > 0
                    dna(toMutate) = (num_msats_alleles+1):(num_msats_alleles+sum(toMutate)); %randi((num_msats_alleles+1):(num_msats_alleles+length(toMutate)),1,length(toMutate));
                    num_msats_alleles = num_msats_alleles + sum(toMutate);
                end
                
                Females(:,3:2+num_msats*2) = reshape(dna(1:size(Females,1)*2*num_msats),size(Females,1),num_msats*2);
                Males(:,2:1+num_msats) = reshape(dna(size(Females,1)*2*num_msats+1:size(Females,1)*2*num_msats+size(Males,1)*num_msats),size(Males,1),num_msats);
                DipMales(:,3:2+num_msats*2) = reshape(dna(size(Females,1)*2*num_msats+size(Males,1)*num_msats+1:size(Females,1)*2*num_msats+size(Males,1)*num_msats+size(DipMales,1)*2*num_msats),size(DipMales,1),num_msats*2);
            end
            
            % find DMs reverting back to females due to mutations
            Q = find(DipMales(:,1) ~= DipMales(:,2));
            Females = [Females; DipMales(Q,:)];
            if isempty(Q)
                DipMales(Q,:) = zeros(0,2);
            else
                DipMales(Q,:) = [];
            end
            
            if inviable == 1 % DMs inviable (immediately die)
                DipMales = zeros(0,2);
            end
            
            % store the numbers 
            N_all(region,t) = N;
            N_p_all(region,t) = N_p;
            F_all(region,t) = size(Females,1); 
            M_all(region,t) = size(Males,1);
            DM_all(region,t) = size(DipMales,1);
            num_alleles_all(region,t) = size(unique([reshape(Females(:,1:2),size(Females,1)*2,1);Males(:,1);reshape(DipMales(:,1:2),size(DipMales,1)*2,1)]),1);          
            f_all(region,t) = f;
            
            % store the individuals
            Females_thisGen = [Females_thisGen; t*ones(size(Females,1),1),region*ones(size(Females,1),1),Females]; % t, region, disperser flag (0 = not dispersed), genotypes(2)
            Males_thisGen = [Males_thisGen; t*ones(size(Males,1),1),region*ones(size(Males,1),1),Males]; % t, region, genotypes(1)
            DipMales_thisGen = [DipMales_thisGen; t*ones(size(DipMales,1),1),region*ones(size(DipMales,1),1),DipMales]; % t, region, genotypes(2)
            
        elseif F > 0 && M+DM == 0 % there are females but no males
            
            Female_ids = 1:F;
            num_offsp = N_p; 
            mothers = randsample(Female_ids,num_offsp,true); % choose mothers to be
            
            % to check if migrants really reproduced or not
            if t > 2 && check_migRate == 1
                Y = find(who_disp_f(:,2)==1); % yes dispersed
                if ~isempty(Y)
                    for l = 1:length(Y)
                        succ_mig_repr(region,t) = succ_mig_repr(region,t) + sum(mothers == Y(l));
                    end
                end
                
            end
            
            sons = Females(mothers,:); % only sons are created
            which_locus = rand(size(sons,1),1)<0.5; % inherit an allele
            sons(:,1) = sons(:,1).*which_locus + sons(:,2).*(1-which_locus);
                     
            if num_msats > 0
            which_locus = rand(size(sons,1),num_msats)<0.5;
            sons(:,3:2+num_msats) = sons(:,3:2+num_msats).*which_locus + sons(:,3+num_msats:2+num_msats*2).*(1-which_locus);
            end
            sons = sons(:,[1,3:2+num_msats]); 
            
            Males = sons;
            Females = []; % no more females
            DipMales = []; % no more DMs
            
            % mutations -- CSD
            dna = Males(:,1)';
            toMutate = (rand(1,length(dna)) < mutr);
            
            if sum(toMutate)>0
                dna(toMutate) = (num_csd_alleles+1):(num_cas_alleles+sum(toMutate));
                num_csd_alleles = num_csd_alleles + sum(toMutate);
            end
            Males(:,1) = dna';
            
            % mutations -- msats
            if num_msats > 0
                dna = reshape(Males(:,2:1+num_msats),size(Males,1)*num_msats,1)';
                toMutate = (rand(1,length(dna)) < mutr_msat);
                
                if sum(toMutate)>0
                    dna(toMutate) = (num_msats_alleles+1):(num_msats_alleles+sum(toMutate)); %randi((num_msats_alleles+1):(num_msats_alleles+length(toMutate)),1,length(toMutate));
                    num_msats_alleles = num_msats_alleles + sum(toMutate);
                end
                Males(:,2:1+num_msats) = reshape(dna,size(Males,1),num_msats);
            end
            
            % store the numbers
            N_all(region,t) = N;
            N_p_all(region,t) = N_p;
            F_all(region,t) = 0;
            M_all(region,t) = size(Males,1);
            DM_all(region,t) = 0;
            num_alleles_all(region,t) = size(unique(Males(:,1)),1);
            f_all(region,t) = f;
            
            % store the individuals (males only -- the population will go extinct in the following generation)
            Males_thisGen = [Males_thisGen; t*ones(size(Males,1),1),region*ones(size(Males,1),1),Males]; % t, region, genotypes(1)
            
        else % F == 0 (there is no female hyperparasitoids)
            Females = [];
            Males = [];
            DipMales = [];
            
            % store the numbers
            N_all(region,t) = N;
            N_p_all(region,t) = N_p;
            F_all(region,t) = 0; 
            M_all(region,t) = 0;
            DM_all(region,t) = 0;
            num_alleles_all(region,t) = 0;
            f_all(region,t) = f;
        end
    end
    
    if sum(F_all(:,t),1) == 0 || sum(M_all(:,t),1) == 0 % the hyperparasitoid went extinct -- display the numbers on the screen
        if plotting == 1
            disp(['Mesochorus only ' num2str(sum(F_all(:,t),1)) ' female(s) and ' num2str(sum(M_all(:,t),1)) ' male(s) left; t = ' num2str(t)])
        end
        N_all(:,t+1:ngen) = poissrnd((1/3)*B_all(:,t+1:ngen)*(1-Hypomort)); % the number of parasitoids in the last generation
        break
    end
 
    % migration -- stepping stone
    [F_all,M_all,DM_all,I_disp_f_all,I_disp_m_all,Females_thisGen,Males_thisGen,DipMales_thisGen] = wasp_migration(F_all,M_all,DM_all,C,u,Females_thisGen,Males_thisGen,DipMales_thisGen,t,h);
    
    num_alleles_Aland(1,t) = length(unique([reshape(Females_thisGen(:,3:4),size(Females_thisGen,1)*2,1);Males_thisGen(:,3);reshape(DipMales_thisGen(:,3:4),size(DipMales_thisGen,1)*2,1)]));
        
    if (t > 300 && mod(t,100) == 0 && FST_on == 1) % calculate Fst and display it on the screen
        disp(['FST_stop, t = ' num2str(t)])
        FST_k = FST_k + 1;
        [FST_all,FST_allLoci,AC_allLoci] = calculateFST(Females_thisGen,FST_all,FST_k,u,num_msats,t,FST_allLoci,AC_allLoci);
    end
    
end

% store Fst and allele counts
FST_all = FST_all(1:FST_k,:);
FST_allLoci = FST_allLoci(1:FST_k,:);
AC_allLoci = AC_allLoci(1:FST_k,:);

%% plotting
tPlotEnd = ngen;
sex_ratio = (M+DM)./F;
sex_ratio_all = sum(M_all+DM_all)./sum(F_all);

figure(2); clf(2)
subplot(5,1,1); semilogy(1:tPlotEnd,sum(F_all(:,1:tPlotEnd)+M_all(:,1:tPlotEnd)+DM_all(:,1:tPlotEnd),1),'g.-');
ylabel('number of Meso individuals'); xlim([1,tPlotEnd]);
subplot(5,1,2); plot(1:tPlotEnd, num_alleles_Aland(1:tPlotEnd),'o-');
ylabel('number of alleles at the CSD locus');xlim([1,tPlotEnd])
subplot(5,1,3); plot(1:tPlotEnd,sum(DM_all(:,1:tPlotEnd))./sum(M_all(:,1:tPlotEnd)+DM_all(:,1:tPlotEnd)),'o-r')
ylabel('DMs/(DMs+Males)');xlim([1,tPlotEnd])
subplot(5,1,4); plot(1:tPlotEnd,sex_ratio_all(1:tPlotEnd),'k-')
xlabel('generations'); ylabel('Sex ratio');xlim([1,tPlotEnd])

figure(2);
subplot(5,2,9)
p_yrs = find(mean(f_all(:,2:end),1)>0)+1;
plot(sum(N_all(:,p_yrs),1)+sum(N_p_all(:,p_yrs),1),mean(f_all(:,p_yrs)),'o','Color',[0.5,0.5,0.5]);
xlabel('Hyp pop size (N+Np)'); ylabel('rate of hyperparasitism');hold on
figure(2);subplot(5,2,10)
plot(sum(F_all(:,p_yrs-1),1)+sum(M_all(:,p_yrs-1),1)+sum(DM_all(:,p_yrs-1),1),mean(f_all(:,p_yrs)),'o','Color',[0.5,0.5,0.5]);
xlabel('Meso pop size (F+M+DM)'); ylabel('rate of hyperparasitism'); hold on

load empirical_data

figure(2); subplot(5,2,9);
plot(numHypo_avg18(1:7)*(1-0)/0.6*(larvPerNest/18),rateOfParas(1:7),'ro','MarkerFaceColor','r');
plot(numHypo_avg18(8:14)*(1-0)/0.6*(larvPerNest/18),rateOfParas(8:14),'ro'); 

figure(2); subplot(5,2,10);
plot(estNumMeso_avg18(1:7)*(1-0)/0.6*(larvPerNest/18),rateOfParas(2:8),'ro','MarkerFaceColor','r'); 
plot(estNumMeso_avg18(8:13)*(1-0)/0.6*(larvPerNest/18),rateOfParas(9:14),'ro'); 
