% parasitoid simulations

% This is the main code. Press Run and it will produce a figure with
% multiple panels showing the results. This program is composed of 5
% m-files and 1 data set (for plotting purpose). Hyperparas_Main,
% Hyperparas_Core, butterfly_tseries, calculateFST, wasp_migration, and
% empirical_data.mat 

% Hyperparas_Core.m contains code to simulate hyperparasitism and compute
% the number of parasites and hyperparasite at yearly time steps (one
% generation in one year)

% butterfly_tseries.m is called by Hyperparas_Core.m and generate a time
% series of butterfly population size. The mean population size and
% standard deviation for each subregion need to be specified within this module. 

% calculateFST.m calculates FST when microsatellites are included in the
% simulations (the code to track msats are commented out in
% Hyperparas_Core.m because we did not use it for the paper).

% wasp_migration.m is called by Hyperparas_Core.m and simulates 2d
% stepping-stone migration of the hyperparasitoid. The dimensions of the
% arena are specified in Hyperparas_Core.m (d1 and d2). 

% parasitoid_data.mat contains data to be used for plotting empirically
% measured values overlayed on simulated values to check their match. Data
% are the number of the hyperparastioids (using 18 butterfly larvae per
% nest in spring), the number of the parasitoids (ditto), and the rate of
% hyperparasitism. All from the samples collected in the field and then
% rared in the lab, as described in the main text. 

clear all; clc;

cd('/Users/etsuko/Documents/Etsuko_workspace/CSD project') % workspace
ngen = 300;
meanScale = 1;
inviable = 0; % 1= diploid males are inviable (die immediately), 0 = sterile (can mate), 2 = full fertility, 3 = stay as females
num_msats = 0; % msat marker loci
num_csd_alleles = 10; % the initial number of CSD alleles
num_msats_alleles = 0; % per marker
mutr = 10^-7; % mutation rate of the CSD alleles
mutr_msat = 10^-4; % mutation rate of the msats
s0 = 0.5; % fraction male offspring
ampShift = ceil(ngen/2); % amplitude shifts at this time
d1 = 4; d2 = 3; % the dimensions of the simulation arena
u = d1*d2; % the number of local populations
h = 0.014; % migration rate of the hyperparasitoid
sig = 0.1; % the standard deviation around the mean rate of hyperparasitism
asymp = 0.62; % parameter a in the equation fit
rise = 26; % parameter b in the equation fit
check_migRate = 1; % 1 = check the rate of migration (migrate and successfully reproduce)
mating_at = 1; % Mating location, 1 = target (destination), 0 = home/source
FST_on = 0; % 1 = count genotypes
Mesomort = 2/3; % Mortality of the hyperparasitoid
Hypomort = 0; % Parasitoid's mortality between birth and hyperparasitism
larvPerNest = 18; % the number of butterfly larvae emerging from a nest in spring
startyr = 8; endyr = startyr+6; % start year and end year (to choose a fluctuation regime)

fluctScale = 1; % fluctuation multiplier (M)
rho = 0.25; % cross-correlation of butterfly populations

RN = randi(10000); % a random number for the seed for the random number generator 
tic;
Hyperparas_Core(RN,ngen,fluctScale,num_csd_alleles,mutr,u,larvPerNest,Mesomort,Hypomort,num_msats,num_msats_alleles,h,sig,asymp,rise,inviable,check_migRate,rho,startyr,d1,d2,mutr_msat,s0,FST_on);
toc