function [B,MUOrder,g] = butterfly_tseries(fluctScale,ngen,u,rho,startyr)

% larvae population for the 12 sub-regions
MU = [9.9402,7.2682,8.6085,7.8625,9.2904,7.2137,8.3910,9.4632,8.1450,7.3096,8.1106,7.7393]; % estimated from the survey data

if startyr == 1 % low fluctuation regime
    sigmas = [0.6227,0.6619,0.6519,1.1510,0.3666,0.7422,0.5154,0.4957,0.7333,0.9383,0.5982,0.8379]*fluctScale; % estimated from the survey data
elseif startyr == 8 % high fluctuation regime
    sigmas = [1.2320,0.9670,0.5787,0.7596,0.7346,0.9045,0.7201,0.4364,1.2319,0.4993,0.8857,0.4728];
end

SIGMA = diag(sigmas.^2); % variance-covariance matrix for the 12 butterfly populations
for i = 1:u
    for j = 1:u
        if i ~= j
            SIGMA(i,j) = sigmas(i)*sigmas(j)*rho;
        end
    end
end

M = zeros(ngen,u);
for i = 1:ngen
    M(i,:) = mvnrnd(MU,SIGMA); % sample random numbers from the multivariate normal distribution
end
B = exp(M)'; % the mean butterfly population size
B = poissrnd(B); % demographic stchasticity (also to have whole numbers for individuals)
g = randperm(u); % shuffle sub-region locations
B = B(g,:);
B(B>10^7) = 10^7; % big numbers can cause memory problems
MUOrder = exp(MU(g)); % record how subregions were shuffled

end


